typst_compile_rust: Compile a '.typ' file and return the output path.

View source: R/extendr-wrappers.R

typst_compile_rustR Documentation

Compile a .typ file and return the output path.

Description

This function uses the Typst Rust library to compile a .typ file to a supported output format and return the output path.

Usage

typst_compile_rust(
  file,
  output = NULL,
  font_path = NULL,
  pdf_standard = NULL,
  output_format = NULL,
  inputs = NULL
)

Arguments

file

Path to an existing .typ file.

output

Optional output path.

font_path

Optional path to font files.

pdf_standard

Optional PDF standard specification.

output_format

Optional output format.

Value

Output path


tynding documentation built on March 31, 2026, 5:06 p.m.