| typst_compile | R Documentation |
.typ file and return the output path.This function uses the Typst Rust library to compile a
.typ file to a supported output format and return the output path.
typst_compile(
file,
output = NULL,
font_path = NULL,
pdf_standard = NULL,
output_format = NULL,
...
)
file |
Path to an existing |
output |
Optional output path. Defaults to the input path with the extension implied by the output format. |
font_path |
Optional path to font files. |
pdf_standard |
Optional PDF standard specification. Options are: : |
output_format |
Optional output format. Supported values are |
... |
Named inputs passed to the Typst document via |
Output path, invisibly.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.