View source: R/extendr-wrappers.R
| typst_compile_rust | R Documentation |
.typ file and return the output path.This function uses the Typst Rust library to compile a
.typ file to a supported output format and return the output path.
typst_compile_rust(
file,
output = NULL,
font_path = NULL,
pdf_standard = NULL,
output_format = NULL,
inputs = NULL
)
file |
Path to an existing |
output |
Optional output path. |
font_path |
Optional path to font files. |
pdf_standard |
Optional PDF standard specification. |
output_format |
Optional output format. |
Output path
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.